@@ -1,7 +1,6 @@
-#!/usr/bin/env python3
 """Tuya asset api."""
 
-from typing import Any, Dict, List
+from typing import Any
 
 from .openapi import TuyaOpenAPI
 
@@ -11,11 +10,9 @@ class TuyaAssetManager:
 
     Attributes:
       api: tuya openapi
-
-
     """
 
-    def __init__(self, api: TuyaOpenAPI):
+    def __init__(self, api: TuyaOpenAPI) -> None:
         """Init Tuya asset manager."""
         self.api = api
 
@@ -23,7 +20,7 @@ class TuyaAssetManager:
     # Asset Management
     # https://developer.tuya.com/docs/cloud/industrial-general-asset-management/4872453fec?id=Kag2yom602i40
 
-    def get_device_list(self, asset_id: str) -> List[str]:
+    def get_device_list(self, asset_id: str) -> list[str]:
         """Get devices by asset_id.
 
         Args:
@@ -32,7 +29,7 @@ class TuyaAssetManager:
         Returns:
           A list of device ids.
         """
-        device_id_list = []
+        device_id_list: list[str] = []
 
         has_next = True
         last_row_key = ""
@@ -44,9 +41,9 @@ class TuyaAssetManager:
             result = response.get("result", {})
             has_next = result.get("has_next", False)
             last_row_key = result.get("last_row_key", "")
-            totalSize = result.get("total_size", 0)
+            total_size = result.get("total_size", 0)
 
-            if len(device_id_list) > totalSize:  # Error
+            if len(device_id_list) > total_size:  # Error
                 raise Exception("get_device_list error, too many devices.")
 
             for item in result.get("list", []):
@@ -54,7 +51,7 @@ class TuyaAssetManager:
 
         return device_id_list
 
-    def get_asset_info(self, asset_id: str) -> Dict[str, Any]:
+    def get_asset_info(self, asset_id: str) -> dict[str, Any]:
         """Get asset's info.
 
         Args:
@@ -63,7 +60,7 @@ class TuyaAssetManager:
         Returns:
             asset's info
         """
-        return self.api.get("/v1.0/iot-02/assets/{}".format(asset_id))
+        return self.api.get(f"/v1.0/iot-02/assets/{asset_id}")
 
     def get_asset_list(self, parent_asset_id: str = "-1") -> list:
         """Get under-nodes unser the current node.
@@ -84,7 +81,9 @@ class TuyaAssetManager:
                 {
                     # "parent_asset_id": parent_asset_id,
                     "asset_id": parent_asset_id,
-                    "last_row_key": last_row_key, "page_size": 100},
+                    "last_row_key": last_row_key,
+                    "page_size": 100,
+                },
             )
             result = response.get("result", {})
             has_next = result.get("has_next", False)
