@@ -1,16 +1,14 @@
-#!/usr/bin/env python3
-# -*- coding: UTF-8 -*-
 """Tuya device api."""
 
-import abc
 import time
+from abc import ABCMeta, abstractclassmethod
 from types import SimpleNamespace
-from typing import Any, Dict, List
+from typing import Any, Literal, Optional
 
 from .openapi import TuyaOpenAPI
+from .openlogging import logger
 from .openmq import TuyaOpenMQ
-from .project_type import ProjectType
-from .logging import logger
+from .tuya_enums import AuthType
 
 PROTOCOL_DEVICE_REPORT = 4
 PROTOCOL_OTHER = 20
@@ -21,7 +19,6 @@ BIZCODE_NAME_UPDATE = "nameUpdate"
 BIZCODE_DPNAME_UPDATE = "dpNameUpdate"
 BIZCODE_BIND_USER = "bindUser"
 BIZCODE_DELETE = "delete"
-BIZCODE_P2P_SIGNAL = "p2pSignal"
 
 
 class TuyaDeviceFunction(SimpleNamespace):
@@ -39,7 +36,7 @@ class TuyaDeviceFunction(SimpleNamespace):
     desc: str
     name: str
     type: str
-    values: Dict[str, Any]
+    values: dict[str, Any]
 
 
 class TuyaDeviceStatusRange(SimpleNamespace):
@@ -101,19 +98,19 @@ class TuyaDevice(SimpleNamespace):
     create_time: int
     update_time: int
 
-    status: Dict[str, Any] = {}
-    function: Dict[str, TuyaDeviceFunction] = {}
-    status_range: Dict[str, str] = {}
+    status: dict[str, Any] = {}
+    function: dict[str, TuyaDeviceFunction] = {}
+    status_range: dict[str, TuyaDeviceStatusRange] = {}
 
     def __eq__(self, other):
         """If devices are the same one."""
         return self.id == other.id
 
 
-class TuyaDeviceListener(metaclass=abc.ABCMeta):
+class TuyaDeviceListener(metaclass=ABCMeta):
     """Tuya device listener."""
 
-    @abc.abstractclassmethod
+    @abstractclassmethod
     def update_device(self, device: TuyaDevice):
         """Update device info.
 
@@ -122,7 +119,7 @@ class TuyaDeviceListener(metaclass=abc.ABCMeta):
         """
         pass
 
-    @abc.abstractclassmethod
+    @abstractclassmethod
     def add_device(self, device: TuyaDevice):
         """Device Added.
 
@@ -131,7 +128,7 @@ class TuyaDeviceListener(metaclass=abc.ABCMeta):
         """
         pass
 
-    @abc.abstractclassmethod
+    @abstractclassmethod
     def remove_device(self, device_id: str):
         """Device removed.
 
@@ -149,18 +146,17 @@ class TuyaDeviceManager:
 
     """
 
-    def __init__(self, api: TuyaOpenAPI, mq: TuyaOpenMQ):
+    def __init__(self, api: TuyaOpenAPI, mq: TuyaOpenMQ) -> None:
         """Tuya device manager init."""
         self.api = api
         self.mq = mq
-        self.device_manage = (
-            SmartHomeDeviceManage(api)
-            if (api.project_type == ProjectType.SMART_HOME)
-            else IndustrySolutionDeviceManage(api)
-        )
+        if api.auth_type == AuthType.SMART_HOME:
+            self.device_manage = SmartHomeDeviceManage(api)
+        else:
+            self.device_manage = IndustrySolutionDeviceManage(api)
 
         mq.add_message_listener(self.on_message)
-        self.device_map: Dict[str, TuyaDevice] = {}
+        self.device_map: dict[str, TuyaDevice] = {}
         self.device_listeners = set()
 
     def __del__(self):
@@ -175,14 +171,12 @@ class TuyaDeviceManager:
             self._on_device_report(data["devId"], data["status"])
         elif protocol == PROTOCOL_OTHER:
             self._on_device_other(data["devId"], data["bizCode"], data)
-        else:
-            pass
 
     def __update_device(self, device: TuyaDevice):
         for listener in self.device_listeners:
             listener.update_device(device)
 
-    def _on_device_report(self, device_id: str, status: List):
+    def _on_device_report(self, device_id: str, status: list):
         device = self.device_map.get(device_id, None)
         if not device:
             return
@@ -195,20 +189,20 @@ class TuyaDeviceManager:
 
         self.__update_device(device)
 
-    def _on_device_other(self, device_id: str, biz_code: str, data: Dict[str, Any]):
+    def _on_device_other(self, device_id: str, biz_code: str, data: dict[str, Any]):
         logger.debug(f"mq _on_device_other-> {device_id} -- {biz_code}")
 
         # bind device to user
         if biz_code == BIZCODE_BIND_USER:
             device_id = data["devId"]
-            devIds = [device_id]
+            device_ids = [device_id]
             # wait for es sync
             time.sleep(1)
 
-            self._update_device_list_info_cache(devIds)
-            self._update_device_list_status_cache(devIds)
+            self._update_device_list_info_cache(device_ids)
+            self._update_device_list_status_cache(device_ids)
 
-            self.update_device_function_cache(devIds)
+            self.update_device_function_cache(device_ids)
 
             if device_id in self.device_map.keys():
                 device = self.device_map.get(device_id)
@@ -235,19 +229,13 @@ class TuyaDeviceManager:
             del self.device_map[device_id]
             for listener in self.device_listeners:
                 listener.remove_device(device.id)
-        elif biz_code == BIZCODE_P2P_SIGNAL:
-            pass
-        else:
-            pass
 
     ##############################
     # Memory Cache
 
     def update_device_list_in_smart_home(self):
         """Update devices status in project type SmartHome."""
-        response = self.api.get(
-            "/v1.0/users/{}/devices".format(self.api.token_info.uid)
-        )
+        response = self.api.get(f"/v1.0/users/{self.api.token_info.uid}/devices")
         if response["success"]:
             for item in response["result"]:
                 device = TuyaDevice(**item)
@@ -262,20 +250,20 @@ class TuyaDeviceManager:
 
         self.update_device_function_cache()
 
-    def update_device_caches(self, devIds: List[str]):
+    def update_device_caches(self, devIds: list[str]):
         """Update devices status in cache.
 
         Update devices info, devices status
 
         Args:
-          devIds(List[str]): devices' id, max 20 once call
+          devIds(list[str]): devices' id, max 20 once call
         """
         self._update_device_list_info_cache(devIds)
         self._update_device_list_status_cache(devIds)
 
         self.update_device_function_cache(devIds)
 
-    def _update_device_list_info_cache(self, devIds: List[str]):
+    def _update_device_list_info_cache(self, devIds: list[str]):
 
         response = self.get_device_list_info(devIds)
         result = response.get("result", {})
@@ -283,7 +271,7 @@ class TuyaDeviceManager:
             device_id = item["id"]
             self.device_map[device_id] = TuyaDevice(**item)
 
-    def _update_device_list_status_cache(self, devIds: List[str]):
+    def _update_device_list_status_cache(self, devIds: list[str]):
 
         response = self.get_device_list_status(devIds)
         for item in response.get("result", []):
@@ -299,7 +287,7 @@ class TuyaDeviceManager:
         """Update device function cache."""
         device_map = (
             filter(lambda d: d.id in devIds, self.device_map.values())
-            if len(devIds) > 0
+            if devIds
             else self.device_map.values()
         )
 
@@ -307,17 +295,17 @@ class TuyaDeviceManager:
             response = self.get_device_specification(device.id)
             if response.get("success"):
                 result = response.get("result", {})
-                functionMap = {}
+                function_map = {}
                 for function in result["functions"]:
                     code = function["code"]
-                    functionMap[code] = TuyaDeviceFunction(**function)
+                    function_map[code] = TuyaDeviceFunction(**function)
 
                 status_range = {}
                 for status in result["status"]:
                     code = status["code"]
                     status_range[code] = TuyaDeviceStatusRange(**status)
 
-                device.function = functionMap
+                device.function = function_map
                 device.status_range = status_range
 
     def add_device_listener(self, listener: TuyaDeviceListener):
@@ -334,7 +322,7 @@ class TuyaDeviceManager:
     # Device Management
     # https://developer.tuya.com/docs/cloud/industrial-general-device-management/2fed20dbd9?id=Kag2t5om665oi
 
-    def get_device_info(self, device_id: str) -> Dict[str, Any]:
+    def get_device_info(self, device_id: str) -> dict[str, Any]:
         """Get device info.
 
         Args:
@@ -342,7 +330,7 @@ class TuyaDeviceManager:
         """
         return self.device_manage.get_device_info(device_id)
 
-    def get_device_list_info(self, devIds: List[str]) -> Dict[str, Any]:
+    def get_device_list_info(self, devIds: list[str]) -> dict[str, Any]:
         """Get devices info.
 
         Args:
@@ -354,7 +342,7 @@ class TuyaDeviceManager:
         """
         return self.device_manage.get_device_list_info(devIds)
 
-    # def updateDeviceInfo(self, device_id: str, info) -> Dict[str, Any]:
+    # def updateDeviceInfo(self, device_id: str, info) -> dict[str, Any]:
     # """Update device information
 
     # Update device information, such as the device name.
@@ -369,7 +357,7 @@ class TuyaDeviceManager:
     # """
     # return self.device_manage.get_device_info(device_id, info)
 
-    def remove_device(self, device_id: str) -> Dict[str, Any]:
+    def remove_device(self, device_id: str) -> dict[str, Any]:
         """Remove device.
 
         Args:
@@ -380,7 +368,7 @@ class TuyaDeviceManager:
         """
         return self.device_manage.remove_device(device_id)
 
-    def remove_device_list(self, devIds: List[str]) -> Dict[str, Any]:
+    def remove_device_list(self, devIds: list[str]) -> dict[str, Any]:
         """Remove devices.
 
         Args:
@@ -391,7 +379,7 @@ class TuyaDeviceManager:
         """
         return self.device_manage.remove_device_list(devIds)
 
-    def get_factory_info(self, device_id: str) -> Dict[str, Any]:
+    def get_factory_info(self, device_id: str) -> dict[str, Any]:
         """Get device's factory info.
 
         Args:
@@ -402,7 +390,7 @@ class TuyaDeviceManager:
         """
         return self.device_manage.get_factory_info(device_id)
 
-    def factory_reset(self, device_id: str) -> Dict[str, Any]:
+    def factory_reset(self, device_id: str) -> dict[str, Any]:
         """Reset device to factory setting.
 
         Args:
@@ -416,7 +404,7 @@ class TuyaDeviceManager:
     # Device Status
     # https://developer.tuya.com/docs/cloud/industrial-general-device-status-query/f8108a55e3?id=Kag2t60ii54jf
 
-    def get_device_status(self, device_id: str) -> Dict[str, Any]:
+    def get_device_status(self, device_id: str) -> dict[str, Any]:
         """Get device status.
 
         Args:
@@ -427,7 +415,7 @@ class TuyaDeviceManager:
         """
         return self.device_manage.get_device_status(device_id)
 
-    def get_device_list_status(self, devIds: List[str]) -> Dict[str, Any]:
+    def get_device_list_status(self, devIds: list[str]) -> dict[str, Any]:
         """Get devices status.
 
         Args:
@@ -441,7 +429,7 @@ class TuyaDeviceManager:
     # Device Control
     # https://developer.tuya.com/docs/cloud/industrial-general-device-control/5d2e6fbe8e?id=Kag2t6n3ony2c
 
-    def get_device_functions(self, device_id: str) -> Dict[str, Any]:
+    def get_device_functions(self, device_id: str) -> dict[str, Any]:
         """Get the Instruction set supported by the device.
 
         Get the Instruction set supported by the device based on the device ID.
@@ -454,7 +442,7 @@ class TuyaDeviceManager:
         """
         return self.device_manage.get_device_functions(device_id)
 
-    def get_category_functions(self, categoryId: str) -> Dict[str, Any]:
+    def get_category_functions(self, categoryId: str) -> dict[str, Any]:
         """Get the instruction set supported by the category.
 
         Get the instruction set supported by the category based on the product category Code
@@ -467,7 +455,7 @@ class TuyaDeviceManager:
         """
         return self.device_manage.get_category_functions(categoryId)
 
-    def get_device_specification(self, device_id: str) -> Dict[str, str]:
+    def get_device_specification(self, device_id: str) -> dict[str, str]:
         """Get device specification attributes.
 
         Obtain device specification attributes according to device ID, including command set and status set.
@@ -480,9 +468,10 @@ class TuyaDeviceManager:
         """
         return self.device_manage.get_device_specification(device_id)
 
-    def send_commands(self,
-                      device_id: str,
-                      commands: List[str]) -> Dict[str, Any]:
+    def send_commands(
+        self, device_id: str, commands: list[dict[str, Any]]
+    ) -> dict[str, Any]:
+
         """Send commands.
 
         Send command to the device.For example:
@@ -499,176 +488,225 @@ class TuyaDeviceManager:
 
     ##############################
 
+    def get_device_stream_allocate(
+        self, device_id: str, stream_type: Literal["flv", "hls", "rtmp", "rtsp"]
+    ) -> Optional[str]:
+        """Get the live streaming address by device ID and the video type.
 
-class DeviceManage(metaclass=abc.ABCMeta):
+        These live streaming video protocol types are available: RTSP, HLS, FLV, and RTMP.
+
+        Args:
+          device_id(str): device id
+          stream_type(str): type of stream
+
+        Returns:
+            None or URL to the requested stream
+        """
+        return self.device_manage.get_device_stream_allocate(device_id, stream_type)
+
+
+class DeviceManage(metaclass=ABCMeta):
     api: TuyaOpenAPI
 
     def __init__(self, api: TuyaOpenAPI):
         self.api = api
 
-    @abc.abstractclassmethod
-    def update_device_caches(self, devIds: List[str]):
+    @abstractclassmethod
+    def update_device_caches(self, devIds: list[str]):
         pass
 
-    @abc.abstractclassmethod
-    def get_device_info(self, device_id: str) -> Dict[str, Any]:
+    @abstractclassmethod
+    def get_device_info(self, device_id: str) -> dict[str, Any]:
         pass
 
-    @abc.abstractclassmethod
-    def get_device_list_info(self, devIds: List[str]) -> Dict[str, Any]:
+    @abstractclassmethod
+    def get_device_list_info(self, devIds: list[str]) -> dict[str, Any]:
         pass
 
-    @abc.abstractclassmethod
-    def get_device_status(self, device_id: str) -> Dict[str, Any]:
+    @abstractclassmethod
+    def get_device_status(self, device_id: str) -> dict[str, Any]:
         pass
 
-    @abc.abstractclassmethod
-    def get_device_list_status(self, devIds: List[str]) -> Dict[str, Any]:
+    @abstractclassmethod
+    def get_device_list_status(self, devIds: list[str]) -> dict[str, Any]:
         pass
 
-    @abc.abstractclassmethod
-    def get_factory_info(self, device_id: str) -> Dict[str, Any]:
+    @abstractclassmethod
+    def get_factory_info(self, device_id: str) -> dict[str, Any]:
         pass
 
-    @abc.abstractclassmethod
-    def factory_reset(self, device_id: str) -> Dict[str, Any]:
+    @abstractclassmethod
+    def factory_reset(self, device_id: str) -> dict[str, Any]:
         pass
 
-    @abc.abstractclassmethod
-    def remove_device(self, device_id: str) -> Dict[str, Any]:
+    @abstractclassmethod
+    def remove_device(self, device_id: str) -> dict[str, Any]:
         pass
 
-    @abc.abstractclassmethod
-    def remove_device_list(self, devIds: List[str]) -> Dict[str, Any]:
+    @abstractclassmethod
+    def remove_device_list(self, devIds: list[str]) -> dict[str, Any]:
         pass
 
-    @abc.abstractclassmethod
-    def get_device_functions(self, device_id: str) -> Dict[str, Any]:
+    @abstractclassmethod
+    def get_device_functions(self, device_id: str) -> dict[str, Any]:
         pass
 
-    @abc.abstractclassmethod
-    def get_category_functions(self, categoryId: str) -> Dict[str, Any]:
+    @abstractclassmethod
+    def get_category_functions(self, categoryId: str) -> dict[str, Any]:
         pass
 
-    @abc.abstractclassmethod
-    def get_device_specification(self, device_id: str) -> Dict[str, str]:
+    @abstractclassmethod
+    def get_device_specification(self, device_id: str) -> dict[str, str]:
         pass
 
-    @abc.abstractclassmethod
-    def send_commands(self, device_id: str, commands: List[str]) -> Dict[str, Any]:
+    @abstractclassmethod
+    def get_device_stream_allocate(
+        self, device_id: str, stream_type: Literal["flv", "hls", "rtmp", "rtsp"]
+    ) -> Optional[str]:
+        pass
+
+    @abstractclassmethod
+    def send_commands(self, device_id: str, commands: list[str]) -> dict[str, Any]:
         pass
 
 
 class SmartHomeDeviceManage(DeviceManage):
-    def update_device_caches(self, devIds: List[str]):
+    def update_device_caches(self, devIds: list[str]):
         pass
 
-    def get_device_info(self, device_id: str) -> Dict[str, Any]:
-        response = self.api.get("/v1.0/devices/{}".format(device_id))
+    def get_device_info(self, device_id: str) -> dict[str, Any]:
+        response = self.api.get(f"/v1.0/devices/{device_id}")
         response["result"].pop("status")
         return response
 
-    def get_device_list_info(self, devIds: List[str]) -> Dict[str, Any]:
-        response = self.api.get(
-            "/v1.0/devices/", {"device_ids": ",".join(devIds)})
+    def get_device_list_info(self, device_ids: list[str]) -> dict[str, Any]:
+        response = self.api.get("/v1.0/devices/", {"device_ids": ",".join(device_ids)})
         if response["success"]:
             for info in response["result"]["devices"]:
                 info.pop("status")
         response["result"]["list"] = response["result"]["devices"]
         return response
 
-    def get_device_status(self, device_id: str) -> Dict[str, Any]:
-        response = self.api.get("/v1.0/devices/{}".format(device_id))
+    def get_device_status(self, device_id: str) -> dict[str, Any]:
+        response = self.api.get(f"/v1.0/devices/{device_id}")
         response["result"] = response["result"]["status"]
         return response
 
-    def get_device_list_status(self, devIds: List[str]) -> Dict[str, Any]:
-        response = self.api.get(
-            "/v1.0/devices/", {"device_ids": ",".join(devIds)})
+    def get_device_list_status(self, device_ids: list[str]) -> dict[str, Any]:
+        response = self.api.get("/v1.0/devices/", {"device_ids": ",".join(device_ids)})
         status_list = []
         if response["success"]:
             for info in response["result"]["devices"]:
-                status_list.append(
-                    {"id": info["id"], "status": info["status"]})
+                status_list.append({"id": info["id"], "status": info["status"]})
 
         response["result"] = status_list
         return response
 
-    def get_factory_info(self, devIds: str) -> Dict[str, Any]:
+    def get_factory_info(self, devIds: str) -> dict[str, Any]:
         return self.api.get(
             "/v1.0/devices/factory-infos", {"device_ids": ",".join(devIds)}
         )
 
-    def factory_reset(self, device_id: str) -> Dict[str, Any]:
-        return self.api.post("/v1.0/devices/{}/reset-factory".format(device_id))
+    def factory_reset(self, device_id: str) -> dict[str, Any]:
+        return self.api.post(f"/v1.0/devices/{device_id}/reset-factory")
 
-    def remove_device(self, device_id: str) -> Dict[str, Any]:
-        return self.api.delete("/v1.0/devices/{}".format(device_id))
+    def remove_device(self, device_id: str) -> dict[str, Any]:
+        return self.api.delete(f"/v1.0/devices/{device_id}")
 
-    def remove_device_list(self, devIds: List[str]) -> Dict[str, Any]:
+    def remove_device_list(self, devIds: list[str]) -> dict[str, Any]:
         raise Exception("Api not support.")
 
-    def get_device_functions(self, device_id: str) -> Dict[str, Any]:
-        return self.api.get("/v1.0/devices/{}/functions".format(device_id))
+    def get_device_functions(self, device_id: str) -> dict[str, Any]:
+        return self.api.get(f"/v1.0/devices/{device_id}/functions")
 
-    def get_category_functions(self, categoryId: str) -> Dict[str, Any]:
-        return self.api.get("/v1.0/functions/{}".format(categoryId))
+    def get_category_functions(self, categoryId: str) -> dict[str, Any]:
+        return self.api.get(f"/v1.0/functions/{categoryId}")
 
     # https://developer.tuya.com/en/docs/cloud/device-control?id=K95zu01ksols7#title-27-Get%20the%20specifications%20and%20properties%20of%20the%20device%2C%20including%20the%20instruction%20set%20and%20status%20set
-    def get_device_specification(self, device_id: str) -> Dict[str, str]:
-        return self.api.get("/v1.0/devices/{}/specifications".format(device_id))
+    def get_device_specification(self, device_id: str) -> dict[str, str]:
+        return self.api.get(f"/v1.0/devices/{device_id}/specifications")
 
-    def send_commands(self, device_id: str, commands: List[str]) -> Dict[str, Any]:
+    def get_device_stream_allocate(
+        self, device_id: str, stream_type: Literal["flv", "hls", "rtmp", "rtsp"]
+    ) -> Optional[str]:
+        """Get the live streaming address by device ID and the video type.
+
+        These live streaming video protocol types are available: RTSP, HLS, FLV, and RTMP.
+
+        https://developer.tuya.com/en/docs/cloud/iot-video-live-stream?id=Kaiuybz0pzle4
+        """
+        response = self.api.post(
+            f"/v1.0/devices/{device_id}/stream/actions/allocate", {"type": stream_type}
+        )
+        if response["success"]:
+            return response["result"]["url"]
+        return None
+
+    def send_commands(
+        self, device_id: str, commands: list[dict[str, Any]]
+    ) -> dict[str, Any]:
         return self.api.post(
-            "/v1.0/devices/{}/commands".format(
-                device_id), {"commands": commands}
+            f"/v1.0/devices/{device_id}/commands", {"commands": commands}
         )
 
 
 class IndustrySolutionDeviceManage(DeviceManage):
-    def update_device_caches(self, devIds: List[str]):
+    def update_device_caches(self, devIds: list[str]):
         pass
 
-    def get_device_info(self, device_id: str) -> Dict[str, Any]:
-        return self.api.get("/v1.0/iot-03/devices/{}".format(device_id))
+    def get_device_info(self, device_id: str) -> dict[str, Any]:
+        return self.api.get(f"/v1.0/iot-03/devices/{device_id}")
 
-    def get_device_list_info(self, devIds: List[str]) -> Dict[str, Any]:
-        return self.api.get("/v1.0/iot-03/devices", {"device_ids": ",".join(devIds)})
+    def get_device_list_info(self, device_ids: list[str]) -> dict[str, Any]:
+        return self.api.get(
+            "/v1.0/iot-03/devices", {"device_ids": ",".join(device_ids)}
+        )
 
-    def get_device_status(self, device_id: str) -> Dict[str, Any]:
-        return self.api.get("/v1.0/iot-03/devices/{}/status".format(device_id))
+    def get_device_status(self, device_id: str) -> dict[str, Any]:
+        return self.api.get(f"/v1.0/iot-03/devices/{device_id}/status")
 
-    def get_device_list_status(self, devIds: List[str]) -> Dict[str, Any]:
+    def get_device_list_status(self, devIds: list[str]) -> dict[str, Any]:
         return self.api.get(
             "/v1.0/iot-03/devices/status", {"device_ids": ",".join(devIds)}
         )
 
-    def get_factory_info(self, device_id: str) -> Dict[str, Any]:
+    def get_factory_info(self, device_id: str) -> dict[str, Any]:
         return self.api.get("/v1.0/iot-03/devices/factory-infos", device_id)
 
-    def factory_reset(self, device_id: str) -> Dict[str, Any]:
+    def factory_reset(self, device_id: str) -> dict[str, Any]:
+        return self.api.delete(f"/v1.0/iot-03/devices/{device_id}/actions/reset")
+
+    def remove_device(self, device_id: str) -> dict[str, Any]:
+        return self.api.delete(f"/v1.0/iot-03/devices/{device_id}")
+
+    def remove_device_list(self, device_ids: list[str]) -> dict[str, Any]:
         return self.api.delete(
-            "/v1.0/iot-03/devices/{}/actions/reset".format(device_id)
+            "/v1.0/iot-03/devices", {"device_ids": ",".join(device_ids)}
         )
 
-    def remove_device(self, device_id: str) -> Dict[str, Any]:
-        return self.api.delete("/v1.0/iot-03/devices/{}".format(device_id))
+    def get_device_functions(self, device_id: str) -> dict[str, Any]:
+        return self.api.get(f"/v1.0/iot-03/devices/{device_id}/functions")
 
-    def remove_device_list(self, devIds: List[str]) -> Dict[str, Any]:
-        return self.api.delete("/v1.0/iot-03/devices", {"device_ids": ",".join(devIds)})
-
-    def get_device_functions(self, device_id: str) -> Dict[str, Any]:
-        return self.api.get("/v1.0/iot-03/devices/{}/functions".format(device_id))
-
-    def get_category_functions(self, categoryId: str) -> Dict[str, Any]:
-        return self.api.get("/v1.0/iot-03/categories/{}/functions".format(categoryId))
+    def get_category_functions(self, categoryId: str) -> dict[str, Any]:
+        return self.api.get(f"/v1.0/iot-03/categories/{categoryId}/functions")
 
     # https://developer.tuya.com/en/docs/cloud/device-control?id=K95zu01ksols7#title-27-Get%20the%20specifications%20and%20properties%20of%20the%20device%2C%20including%20the%20instruction%20set%20and%20status%20set
-    def get_device_specification(self, device_id: str) -> Dict[str, str]:
-        return self.api.get("/v1.0/iot-03/devices/{}/specification".format(device_id))
+    def get_device_specification(self, device_id: str) -> dict[str, str]:
+        return self.api.get(f"/v1.0/iot-03/devices/{device_id}/specification")
+
+    def get_device_stream_allocate(
+        self, device_id: str, stream_type: Literal["flv", "hls", "rtmp", "rtsp"]
+    ) -> Optional[str]:
+        """Get the live streaming address by device ID and the video type.
+
+        Not implemented for this device manager.
+        """
+        return None
+
+    def send_commands(
+        self, device_id: str, commands: list[dict[str, Any]]
+    ) -> dict[str, Any]:
 
-    def send_commands(self, device_id: str, commands: List[str]) -> Dict[str, Any]:
         return self.api.post(
-            "/v1.0/iot-03/devices/{}/commands".format(
-                device_id), {"commands": commands}
+            f"/v1.0/iot-03/devices/{device_id}/commands", {"commands": commands}
         )
