@@ -1,22 +1,22 @@
-#!/usr/bin/env python3
-# -*- coding: UTF-8 -*-
 """Tuya Open IOT HUB which base on MQTT."""
 
 import base64
 import json
-import time
 import threading
+import time
 import uuid
-from typing import Any, Callable, Dict
+from typing import Any, Callable
 from urllib.parse import urlsplit
-from paho.mqtt import client as mqtt
+from typing import Optional
+
 from Crypto.Cipher import AES
+from paho.mqtt import client as mqtt
 
 from .openapi import TuyaOpenAPI
-from .project_type import ProjectType
-from .logging import logger
+from .openlogging import logger
+from .tuya_enums import AuthType
 
-LINK_ID = "tuya-iot-app-sdk-python.{}".format(uuid.uuid1())
+LINK_ID = f"tuya-iot-app-sdk-python.{uuid.uuid1()}"
 GCM_TAG_LENGTH = 16
 CONNECT_FAILED_NOT_AUTHORISED = 5
 
@@ -24,25 +24,16 @@ CONNECT_FAILED_NOT_AUTHORISED = 5
 class TuyaMQConfig:
     """Tuya mqtt config."""
 
-    url = ""
-    client_id = ""
-    username = ""
-    password = ""
-    source_topic = {}
-    sink_topic = {}
-    expireTime = 0
-
-    def __init__(self, mqConfigResponse: Dict[str, Any] = {}):
+    def __init__(self, mqConfigResponse: dict[str, Any] = {}) -> None:
         """Init TuyaMQConfig."""
         result = mqConfigResponse.get("result", {})
-
         self.url = result.get("url", "")
         self.client_id = result.get("client_id", "")
         self.username = result.get("username", "")
         self.password = result.get("password", "")
         self.source_topic = result.get("source_topic", {})
         self.sink_topic = result.get("sink_topic", {})
-        self.expireTime = result.get("expire_time", 0)
+        self.expire_time = result.get("expire_time", 0)
 
 
 class TuyaOpenMQ(threading.Thread):
@@ -54,15 +45,16 @@ class TuyaOpenMQ(threading.Thread):
       openapi: tuya openapi
     """
 
-    def __init__(self, api: TuyaOpenAPI):
+    def __init__(self, api: TuyaOpenAPI) -> None:
         """Init TuyaOpenMQ."""
         threading.Thread.__init__(self)
         self.api: TuyaOpenAPI = api
         self._stop_event = threading.Event()
         self.client = None
+        self.mq_config = None
         self.message_listeners = set()
 
-    def _get_mqtt_config(self) -> TuyaMQConfig:
+    def _get_mqtt_config(self) -> Optional[TuyaMQConfig]:
         response = self.api.post(
             "/v1.0/iot-03/open-hub/access-config",
             {
@@ -71,7 +63,7 @@ class TuyaOpenMQ(threading.Thread):
                 "link_type": "mqtt",
                 "topics": "device",
                 "msg_encrypted_version": "2.0"
-                if (self.api.project_type == ProjectType.INDUSTY_SOLUTIONS)
+                if (self.api.auth_type == AuthType.CUSTOM)
                 else "1.0",
             },
         )
@@ -81,12 +73,10 @@ class TuyaOpenMQ(threading.Thread):
 
         return TuyaMQConfig(response)
 
-    def _decode_mq_message(
-        self, b64msg: str, password: str, t: str
-    ) -> Dict[str, Any]:
+    def _decode_mq_message(self, b64msg: str, password: str, t: str) -> dict[str, Any]:
         key = password[8:24]
 
-        if self.api.project_type == ProjectType.SMART_HOME:
+        if self.api.auth_type == AuthType.SMART_HOME:
             cipher = AES.new(key.encode("utf8"), AES.MODE_ECB)
             msg = cipher.decrypt(base64.b64decode(b64msg))
             padding_bytes = msg[-1]
@@ -98,16 +88,16 @@ class TuyaOpenMQ(threading.Thread):
 
             # get iv buffer
             iv_length = int.from_bytes(buffer[0:4], byteorder="big")
-            iv_buffer = buffer[4: iv_length + 4]
+            iv_buffer = buffer[4 : iv_length + 4]
 
             # get data buffer
-            data_buffer = buffer[iv_length + 4: len(buffer) - GCM_TAG_LENGTH]
+            data_buffer = buffer[iv_length + 4 : len(buffer) - GCM_TAG_LENGTH]
 
             # aad
             aad_buffer = str(t).encode("utf8")
 
             # tag
-            tag_buffer = buffer[len(buffer) - GCM_TAG_LENGTH:]
+            tag_buffer = buffer[len(buffer) - GCM_TAG_LENGTH :]
 
             cipher = AES.new(key.encode("utf8"), AES.MODE_GCM, nonce=iv_buffer)
             cipher.update(aad_buffer)
@@ -122,7 +112,7 @@ class TuyaOpenMQ(threading.Thread):
         else:
             logger.debug("disconnect")
 
-    def _on_connect(self, mqttc: mqtt.Client, userData: Any, flags, rc):
+    def _on_connect(self, mqttc: mqtt.Client, user_data: Any, flags, rc):
         logger.debug(f"connect flags->{flags}, rc->{rc}")
         if rc == 0:
             for (key, value) in self.mq_config.source_topic.items():
@@ -130,38 +120,30 @@ class TuyaOpenMQ(threading.Thread):
         elif rc == CONNECT_FAILED_NOT_AUTHORISED:
             self.__run_mqtt()
 
-    def _on_message(
-        self, mqttc: mqtt.Client, userData: Any, msg: mqtt.MQTTMessage
-    ):
+    def _on_message(self, mqttc: mqtt.Client, user_data: Any, msg: mqtt.MQTTMessage):
         logger.debug(f"payload-> {msg.payload}")
 
-        msgDict = json.loads(msg.payload.decode("utf8"))
+        msg_dict = json.loads(msg.payload.decode("utf8"))
 
-        # topic = msg.topic
-        # protocol = msgDict.get("protocol", 0)
-        # pv = msgDict.get("pv", "")
-        # data = msgDict.get("data", "")
+        t = msg_dict.get("t", "")
 
-        t = msgDict.get("t", "")
-
-        mq_config = userData["mqConfig"]
-        decryptedData = self._decode_mq_message(
-            msgDict["data"], mq_config.password, t)
-        if decryptedData is None:
+        mq_config = user_data["mqConfig"]
+        decrypted_data = self._decode_mq_message(
+            msg_dict["data"], mq_config.password, t
+        )
+        if decrypted_data is None:
             return
 
-        msgDict["data"] = decryptedData
-        logger.debug(f"on_message: {msgDict}")
+        msg_dict["data"] = decrypted_data
+        logger.debug(f"on_message: {msg_dict}")
 
         for listener in self.message_listeners:
-            listener(msgDict)
+            listener(msg_dict)
 
-    def _on_subscribe(
-        self, mqttc: mqtt.Client, userData: Any, mid, granted_qos
-    ):
+    def _on_subscribe(self, mqttc: mqtt.Client, user_data: Any, mid, granted_qos):
         logger.debug(f"_on_subscribe: {mid}")
 
-    def _on_log(self, mqttc: mqtt.Client, userData: Any, level, string):
+    def _on_log(self, mqttc: mqtt.Client, user_data: Any, level, string):
         logger.debug(f"_on_log: {string}")
 
     def run(self):
@@ -170,7 +152,7 @@ class TuyaOpenMQ(threading.Thread):
             self.__run_mqtt()
 
             # reconnect every 2 hours required.
-            time.sleep(self.mq_config.expireTime - 60)
+            time.sleep(self.mq_config.expire_time - 60)
 
     def __run_mqtt(self):
         mq_config = self._get_mqtt_config()
